@@ -10,6 +10,10 @@ ECONET_VERSION: int = 0x05
 
 READER_BUFFER_SIZE: int = 1000
 
+UID_BASE: int = 32
+UID_BASE_BITS: int = 5
+UID_CHAR_BITS: int = 8
+
 WLAN_ENCRYPTION_UNKNOWN = 0
 WLAN_ENCRYPTION_NONE = 1
 WLAN_ENCRYPTION_WEP = 2
@@ -23,56 +27,144 @@ WLAN_ENCRYPTION = (
     WLAN_ENCRYPTION_WPA2,
 )
 
-MODULE_A: str = "moduleA"
-MODULE_B: str = "moduleB"
-MODULE_C: str = "moduleC"
-MODULE_LAMBDA: str = "moduleLambda"
-MODULE_ECOSTER: str = "moduleEcoSTER"
-MODULE_PANEL: str = "modulePanel"
+DEFAULT_IP = "0.0.0.0"
+DEFAULT_NETMASK = "255.255.255.0"
 
+MODULE_PANEL: str = "MODULE_PANEL"
+MODULE_A: str = "MODULE_A"
+MODULE_B: str = "MODULE_B"
+MODULE_C: str = "MODULE_C"
+MODULE_LAMBDA: str = "MODULE_LAMBDA"
+MODULE_ECOSTER: str = "MODULE_ECOSTER"
 MODULES: list = (
+    MODULE_PANEL,
     MODULE_A,
     MODULE_B,
     MODULE_C,
     MODULE_LAMBDA,
     MODULE_ECOSTER,
-    MODULE_PANEL,
 )
 
-UID_BASE: int = 32
-UID_BASE_BITS: int = 5
-UID_CHAR_BITS: int = 8
-
 MODES: list = (
-    "OFF",
-    "STARTING",
-    "KINDLING",
-    "HEATING",
-    "SUPERVISION",
-    "COOLING",
-    "STANDBY",
+    "Off",
+    "Starting",
+    "Kindling",
+    "Heating",
+    "Supervision",
+    "Cooling",
+    "Standby",
 )
 
-TEMP_NAMES: list = (
-    "tempCO",
-    "tempFeeder",
-    "tempCWU",
-    "tempExternalSensor",
-    "tempBack",
-    "tempFlueGas",
-    "tempOpticalSensor",
-    "tempUpperBuffer",
-    "tempLowerBuffer",
-    "tempUpperSolar",
-    "tempLowerSolar",
-    "tempFireplace",
-    "totalGain",
-    "tempHydraulicCoupler",
-    "tempExchanger",
-    "tempAirIn",
-    "tempAirOut",
+MIXER_TEMP: str = "TEMP"
+MIXER_TARGET: str = "TARGET"
+MIXER_PUMP: str = "PUMP"
+
+ECOSTER_CONTACTS: str = "CONTACTS"
+ECOSTER_SCHEDULE: str = "SCHEDULE"
+ECOSTER_MODE: str = "MODE"
+ECOSTER_TEMP: str = "TEMP"
+ECOSTER_TARGET: str = "TARGET"
+
+DATA_ALARMS: str = "ALARMS"
+DATA_CO_STATUS: str = "CO_STATUS"
+DATA_CO_TARGET: str = "CO_TARGET"
+DATA_CWU_STATUS: str = "CWU_STATUS"
+DATA_CWU_TARGET: str = "CWU_TARGET"
+DATA_FAN_POWER: str = "FAN_POWER"
+DATA_FRAMES: str = "FRAMES"
+DATA_FUEL_CONSUMPTION: str = "FUEL_CONSUMPTION"
+DATA_FUEL_LEVEL: str = "FUEL_LEVEL"
+DATA_LAMBDA_LEVEL: str = "LAMBDA_LEVEL"
+DATA_LAMBDA_STATUS: str = "LAMBDA_STATUS"
+DATA_LAMBDA_TARGET: str = "LAMBDA_TARGET"
+DATA_MIXERS: str = "MIXERS"
+DATA_MODE: str = "MODE"
+DATA_POWER: str = "POWER"
+DATA_LOAD: str = "LOAD"
+DATA_THERMOSTAT: str = "THERMOSTAT"
+DATA_THERMOSTATS: str = "THERMOSTATS"
+DATA_TRANSMISSION: str = "TRANSMISSION"
+
+TEMPERATURES: list = (
+    "CO_TEMP",
+    "FEEDER_TEMP",
+    "CWU_TEMP",
+    "OUTSIDE_TEMP",
+    "BACK_TEMP",
+    "EXHAUST_TEMP",
+    "OPTICAL_TEMP",
+    "UPPER_BUFFER_TEMP",
+    "LOWER_BUFFER_TEMP",
+    "UPPER_SOLAR_TEMP",
+    "LOWER_SOLAR_TEMP",
+    "FIREPLACE_TEMP",
+    "TOTAL_GAIN",
+    "HYDRAULIC_COUPLER_TEMP",
+    "EXCHANGER_TEMP",
+    "AIR_IN_TEMP",
+    "AIR_OUT_TEMP",
 )
 
+OUTPUTS: list = (
+    "FAN",
+    "FEEDER",
+    "CO_PUMP",
+    "CWU_PUMP",
+    "CICULATION_PUMP",
+    "LIGHTER",
+    "ALARM",
+    "OUTER_BOILER",
+    "FAN2_EXHAUST",
+    "FEEDER2",
+    "OUTER_FEEDER",
+    "SOLAR_PUMP",
+    "FIREPLACE_PUMP",
+    "GCZ_CONTACT",
+    "BLOW_FAN1",
+    "BLOW_FAN2",
+)
+
+DATA_CO_PUMP_FLAG: str = "CO_PUMP_FLAG"
+DATA_CWU_PUMP_FLAG: str = "CWU_PUMP_FLAG"
+DATA_CIRCULATION_PUMP_FLAG: str = "CIRCULATION_PUMP_FLAG"
+DATA_SOLAR_PUMP_FLAG: str = "SOLAR_PUMP_FLAG"
+FLAGS: list = (
+    DATA_CO_PUMP_FLAG,
+    DATA_CWU_PUMP_FLAG,
+    DATA_CIRCULATION_PUMP_FLAG,
+    DATA_SOLAR_PUMP_FLAG,
+)
+
+STATUSES: list = (
+    "CO_TARGET",
+    "CO_STATUS",
+    "CWU_TARGET",
+    "CWU_STATUS",
+)
+
+CURRENT_DATA: list = [
+    DATA_ALARMS,
+    DATA_FAN_POWER,
+    DATA_FRAMES,
+    DATA_FUEL_CONSUMPTION,
+    DATA_FUEL_LEVEL,
+    DATA_LAMBDA_LEVEL,
+    DATA_LAMBDA_STATUS,
+    DATA_LAMBDA_TARGET,
+    DATA_LOAD,
+    DATA_MIXERS,
+    DATA_MODE,
+    DATA_POWER,
+    DATA_THERMOSTAT,
+    DATA_THERMOSTATS,
+    DATA_TRANSMISSION,
+]
+CURRENT_DATA.extend(TEMPERATURES)
+CURRENT_DATA.extend(OUTPUTS)
+CURRENT_DATA.extend(FLAGS)
+CURRENT_DATA.extend(STATUSES)
+CURRENT_DATA.extend(MODULES)
+
 EDITABLE_PARAMS: list = (
     "AIRFLOW_POWER_100",
     "AIRFLOW_POWER_50",
