@@ -1,9 +1,17 @@
 """Contains classes for supported devices."""
 from __future__ import annotations
 
-from .constants import EDITABLE_PARAMS, MODULE_A
+from .constants import (
+    CURRENT_DATA,
+    DATA_FRAMES,
+    DATA_MODE,
+    EDITABLE_PARAMS,
+    MODES,
+    MODULE_PANEL,
+)
 from .frame import Request
 from .frames.requests import BoilerControl, SetParameter
+from .storage import FrameBucket
 
 
 class EcoMAX:
@@ -12,13 +20,14 @@ class EcoMAX:
     Passed to the user-defined callback method.
     """
 
-    software: str = None
     product: str = None
     uid: str = None
     password: str = None
     struct: list = []
+    _queue: list[Request] = []
     _parameters: dict = {}
     _data: dict = {}
+    _is_on: bool = None
 
     def __init__(self, data: dict = None, parameters: dict = None):
         """Create ecoMAX device representation."""
@@ -29,6 +38,8 @@ class EcoMAX:
         if parameters is not None:
             self.set_parameters(parameters)
 
+        self.bucket = FrameBucket()
+
     def __getattr__(self, name: str) -> None:
         """Gets current data item as class attribute.
 
@@ -52,8 +63,12 @@ class EcoMAX:
         value -- attribute value
         """
         key = name.upper()
+        if key in self._data:
+            raise AttributeError()
+
         if key in self._parameters:
             self._parameters[key].set(value)
+            self._queue.append(self._parameters[key].request)
         else:
             self.__dict__[name] = value
 
@@ -67,28 +82,10 @@ class EcoMAX:
         Keyword arguments:
         data - data parsed from CurrentData response frame
         """
-        self._data["MODE"] = data["modeString"]
-        self._data["POWER"] = data["boilerPowerKW"]
-        self._data["POWER_PCT"] = data["boilerPower"]
-        self._data["CO_TARGET"] = data["tempCOSet"]
-        self._data["CO_TEMP"] = data["temperatures"]["tempCO"]
-        self._data["CO_PUMP"] = data["outputs"]["pumpCOWorks"]
-        self._data["EXHAUST_TEMP"] = data["temperatures"]["tempFlueGas"]
-        self._data["OUTSIDE_TEMP"] = data["temperatures"]["tempExternalSensor"]
-        self._data["FAN"] = data["outputs"]["fanWorks"]
-        self._data["FAN_POWER"] = data["fanPower"]
-        self._data["CWU_TARGET"] = data["tempCWUSet"]
-        self._data["CWU_TEMP"] = data["temperatures"]["tempCWU"]
-        self._data["CWU_PUMP"] = data["outputs"]["pumpCWUWorks"]
-        self._data["FEEDER"] = data["outputs"]["feederWorks"]
-        self._data["FEEDER_TEMP"] = data["temperatures"]["tempFeeder"]
-        self._data["FUEL_LEVEL"] = data["fuelLevel"]
-        self._data["FUEL_FLOW"] = data["fuelStream"]
-        self._data["LIGHTER"] = data["outputs"]["lighterWorks"]
-        self.software = data["versions"][MODULE_A]
-        self._parameters["BOILER_CONTROL"] = Parameter(
-            name="BOILER_CONTROL", value=int(data["mode"] != 0), min_=0, max_=1
-        )
+        self.bucket.fill(data[DATA_FRAMES])
+        for name, value in data.items():
+            if name in CURRENT_DATA:
+                self._data[name] = value
 
     def has_parameters(self) -> bool:
         """Check if ecoMAX instance has parameters."""
@@ -105,6 +102,45 @@ class EcoMAX:
                     max_=parameter["max"],
                 )
 
+        self._parameters["BOILER_CONTROL"] = Parameter(
+            name="BOILER_CONTROL", value=int(self.is_on), min_=0, max_=1
+        )
+
+    @property
+    def software(self) -> str:
+        """Returns software version."""
+        try:
+            return self._data[MODULE_PANEL]
+        except KeyError:
+            return None
+
+    @property
+    def is_on(self) -> bool:
+        """Returns current state."""
+        try:
+            return bool(self._data[DATA_MODE] != 0)
+        except KeyError:
+            return False
+
+    @property
+    def mode(self) -> str:
+        """Returns current mode."""
+        if self._data:
+            mode = self._data[DATA_MODE]
+            try:
+                return MODES[mode]
+            except IndexError:
+                pass
+
+        return "Unknown"
+
+    @property
+    def queue(self):
+        """Clears and returns changed parameters queue."""
+        queue = self._queue
+        self._queue = []
+        return queue
+
     @property
     def data(self):
         """Returns EcoMAX data."""
@@ -118,9 +154,9 @@ class EcoMAX:
     @property
     def changes(self) -> list[Parameter]:
         """Returns changed device parameters."""
-        return [
-            v.queue() for _, v in self._parameters.items() if v.changed and not v.queued
-        ]
+        changes = self.queue
+        changes.extend(self.bucket.queue)
+        return changes
 
     def __str__(self) -> str:
         """Converts EcoMAX instance to a string."""
@@ -137,7 +173,7 @@ Password:       {self.password}
                 output += f" -- {k}: {v}\n"
 
         if self.has_parameters():
-            output += "\nRegulator parameters:\n"
+            output += "\nEditable parameters:\n"
             for _, parameter in self._parameters.items():
                 output += f" -- {parameter}\n"
 
@@ -147,9 +183,6 @@ Password:       {self.password}
 class Parameter:
     """Device parameter representation."""
 
-    _changed = False
-    _queued = False
-
     def __init__(self, name: str, value, min_: int, max_: int):
         self.name = name
         self.value = int(value)
@@ -164,12 +197,6 @@ class Parameter:
         """
         if self.value != value and self.min_ <= value <= self.max_:
             self.value = value
-            self._changed = True
-
-    def queue(self) -> Parameter:
-        """Marks parameter as queued to write."""
-        self._queued = True
-        return self
 
     @property
     def request(self) -> Request:
@@ -179,16 +206,6 @@ class Parameter:
 
         return SetParameter(data=self.__dict__)
 
-    @property
-    def queued(self) -> bool:
-        """Returns queued property."""
-        return self._queued
-
-    @property
-    def changed(self) -> bool:
-        """Returns changed property."""
-        return self._changed
-
     def __repr__(self) -> str:
         """Returns serializable string representation."""
         return f"""Parameter(
