@@ -5,17 +5,15 @@ connection.
 from __future__ import annotations
 
 import asyncio
-from asyncio.exceptions import CancelledError
 from collections.abc import Callable
 import os
 import sys
 
-from .constants import WLAN_ENCRYPTION
+from .constants import DEFAULT_IP, DEFAULT_NETMASK, WLAN_ENCRYPTION
 from .devices import EcoMAX
 from .exceptions import ChecksumError, FrameTypeError, LengthError
 from .frame import Frame
 from .frames import requests, responses
-from .storage import FrameBucket
 from .stream import FrameReader, FrameWriter
 
 
@@ -28,7 +26,6 @@ class EcoNET:
     port: int = None
     closed: bool = True
     _net: dict = {}
-    _tasks = None
     _writer_close = None
 
     def __init__(self, host: str, port: int, **kwargs):
@@ -45,7 +42,6 @@ class EcoNET:
         self.host = host
         self.port = port
         self.kwargs = kwargs
-        self.bucket = FrameBucket()
         self.ecomax = EcoMAX()
 
     def __enter__(self):
@@ -62,7 +58,7 @@ class EcoNET:
     port = {self.port},
     kwargs = {self.kwargs}
 )
-""".strip()
+"""
 
     async def _callback(
         self, callback: Callable[EcoMAX, EcoNET], interval: int
@@ -99,12 +95,8 @@ class EcoNET:
         elif frame.is_type(responses.Password):
             self.ecomax.password = frame.data
 
-        elif frame.is_type(responses.CurrentData):
-            self.bucket.fill(writer, frame.data["frame_versions"])
-            self.ecomax.set_data(frame.data)
-
         elif frame.is_type(responses.RegData) or frame.is_type(responses.CurrentData):
-            self.bucket.fill(writer, frame.data["frame_versions"])
+            self.ecomax.set_data(frame.data)
 
         elif frame.is_type(responses.Parameters):
             self.ecomax.set_parameters(frame.data)
@@ -117,13 +109,18 @@ class EcoNET:
                 # Respond to check device frame only if queue is empty.
                 writer.queue(frame.response(data=self._net))
 
+        writer.collect(self.ecomax.changes)
+
     async def _read(self, reader: FrameReader, writer: FrameWriter) -> None:
         """Handles connection reads."""
         while True:
+            if self.closed:
+                await writer.close()
+                break
+
             try:
                 frame = await reader.read()
                 asyncio.create_task(self._process(frame, writer))
-                writer.collect(self.ecomax.changes)
                 await writer.process_queue()
             except ChecksumError:
                 pass
@@ -146,14 +143,9 @@ class EcoNET:
         self.closed = False
         reader, writer = [FrameReader(reader), FrameWriter(writer)]
         writer.queue(requests.Password())
-
-        self._tasks = asyncio.gather(
-            self._read(reader, writer), self._callback(callback, interval)
-        )
-
+        asyncio.create_task(self._callback(callback, interval))
         self._writer_close = writer.close  # Avoid stream garbage collection message.
-
-        await self._tasks
+        await self._read(reader, writer)
 
     def run(self, callback: Callable[EcoMAX, EcoNET], interval: int = 1) -> None:
         """Run connection in the event loop.
@@ -169,11 +161,9 @@ class EcoNET:
             sys.exit(asyncio.run(self.task(callback, interval)))
         except KeyboardInterrupt:
             pass
-        except CancelledError:
-            pass
 
     def set_eth(
-        self, ip: str, netmask: str = "255.255.255.0", gateway: str = "0.0.0.0"
+        self, ip: str, netmask: str = DEFAULT_NETMASK, gateway: str = DEFAULT_IP
     ) -> None:
         """Sets eth parameters to pass to ecoMax device.
         Used for informational purpoises only.
@@ -195,8 +185,8 @@ class EcoNET:
         ssid: str,
         ip: str,
         encryption: int = WLAN_ENCRYPTION[1],
-        netmask: str = "255.255.255.0",
-        gateway: str = "0.0.0.0",
+        netmask: str = DEFAULT_NETMASK,
+        gateway: str = DEFAULT_IP,
         quality: int = 100,
     ) -> None:
         """Sets wlan parameters to pass to ecoMAX device.
@@ -225,8 +215,4 @@ class EcoNET:
 
     def close(self) -> None:
         """Closes opened connection."""
-        if self._tasks is not None:
-            self._tasks.cancel()
-            self._tasks = None
-
         self.closed = True
